Repository Analysis

tile-ai/tilelang

Domain-specific language designed to streamline the development of high-performance GPU/CPU/Accelerators kernels

22.2 Moderate AI signal View on GitHub

Analysis Overview

This report presents the forensic synthetic code analysis of tile-ai/tilelang, a Python project with 7,301 GitHub stars. SynthScan v2.0 examined 327,538 lines of code across 1333 source files, recording 5370 pattern matches distributed across 23 syntactic categories. The overall adjusted score of 22.2 places this repository in the Moderate AI signal band.

The scanner applied 160+ deterministic lexical heuristics, multi-line block detectors, abstract syntax tree depth profilers, and a cross-file Jaccard similarity matrix to construct a statistically normalised synthetic code estimate. All matches are individually weighted by severity coefficient and contextual multiplier before summation, and the resulting headline score is temporally discounted to account for the repository's development history relative to the commercial emergence of large language model coding tooling (November 2022 onward).

22.2
Adjusted Score
22.2
Raw Score
100%
Time Factor
2026-08-28
Last Push
7.3K
Stars
Python
Language
327.5K
Lines of Code
1.3K
Files
5.4K
Pattern Hits
2026-08-29
Scan Date
0.16
HC Hit Rate

What These Metrics Mean

Adjusted Score
Primary synthetic code indicator. Raw score normalised per 1,000 lines of code and multiplied by the temporal discount factor. This is the definitive comparative metric — use it to rank repositories by AI authorship density.
Raw Score
The unmodified sum of all severity-weighted, context-multiplied pattern match scores before temporal discounting. Reflects the absolute signal strength independent of when the repository was last active.
Time Factor
The temporal discount multiplier (0–100%) applied to the raw score. Repositories last updated before ChatGPT's launch (Nov 2022) receive a 5% factor. Full signal is only assigned to repositories active in the post-adoption era (Jan 2024+).
Pattern Hits
Total count of individual pattern matches across all files and categories. A high hit count with a low score may indicate a very large codebase with isolated AI snippets; a low count with a high score indicates dense, concentrated AI signatures.
HC Hit Rate
High+Critical pattern hits per file, averaged across the repository. This orthogonal signal catches repositories where a few files are densely packed with high-severity AI tells — a strong indicator even when the normalised score appears moderate due to codebase size.
Lines of Code / Files
Total lines and files analysed. The scanner examines 94 file extensions. These denominators are used to normalise the score, enabling fair comparison between repositories of vastly different sizes.

Score History

This chart maps the temporal evolution of the adjusted synthetic code score across successive scan runs. An upward trajectory indicates ongoing incorporation of AI-generated code or expanding LLM-assisted scaffolding; a stable or declining trajectory may reflect active human refactoring, code removal, or the adoption of stricter authorship policies. The dashed secondary line (right axis) independently tracks total raw pattern hit count, which can diverge from the normalised score when codebase size changes significantly between scans.

Severity Breakdown

Classifies detected patterns by their diagnostic confidence and structural impact. CRITICAL patterns (coefficient 10) represent definitive synthetic signatures — hallucinated imports, explicit LLM attribution metadata — virtually never produced by human authors. HIGH (5) indicates strong structural tells such as cross-file repetition or cross-linguistic idioms. MEDIUM (2) covers recognisable conversational padding and AI-specific vocabulary. LOW (1) captures subtle indicators like tautological comments and generic boilerplate that require density to carry independent signal.

CRITICAL 3HIGH 213MEDIUM 512LOW 4642

Directory Score Breakdown

This horizontal bar chart decomposes the repository's raw synthetic code score by top-level directory, allowing you to pinpoint precisely which modules or components carry the highest AI authorship density. Directories with disproportionately high scores relative to their size warrant targeted manual review: concentrated AI signatures often trace back to mass-generated configuration layers, auto-ported test suites, LLM-scaffolded boilerplate classes, or entire subsystems authored under heavy copilot assistance. Use this view to prioritise your human code-review effort.

Pattern Findings

The scanner identified 5370 distinct pattern matches across 23 syntactic categories. Each entry below represents a discrete location in the source code where the engine recorded a statistically significant AI authorship indicator. Expand any category row to inspect the individual file paths, line numbers, code snippets, and the lexical context (CODE, COMMENT, or STRING) in which each match was detected.

Reading the findings table: The Severity column indicates the diagnostic confidence level (CRITICAL / HIGH / MEDIUM / LOW). The Context column identifies whether the match occurred inside executable code, an inline comment, or a string literal — comment-context matches receive a ×1.5 weight because LLMs systematically over-annotate. The ⚡ bolt icon marks clustered matches: three or more patterns within a 10-line window, each receiving an additional ×1.5 density multiplier as dense clusters constitute far stronger evidence of synthetic authorship than isolated hits.

Hyper-Verbose Identifiers2354 hits · 2345 pts
SeverityFileLineSnippetContext
LOWbenchmark/matmul_metal/benchmark_matmul_metal.py52def matmul_cooperative_tensor_shared_c(CODE
LOWbenchmark/matmul_metal/benchmark_matmul_metal.py84def matmul_cooperative_tensor_global(CODE
LOW…arse_attention/benchmark_tilelang_block_sparse_fmha.py14def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False):CODE
LOW…arse_attention/benchmark_tilelang_block_sparse_fmha.py26def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False):CODE
LOW…arse_attention/benchmark_tilelang_block_sparse_fmha.py170def benchmark_topk_sparse_attention():CODE
LOW…ksparse_attention/benchmark_torch_block_sparse_fmha.py9def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False):CODE
LOW…ksparse_attention/benchmark_torch_block_sparse_fmha.py21def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False):CODE
LOW…ksparse_attention/benchmark_torch_block_sparse_fmha.py29def benchmark_topk_sparse_attention():CODE
LOW…sparse_attention/benchmark_triton_block_sparse_fmha.py14def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False):CODE
LOW…sparse_attention/benchmark_triton_block_sparse_fmha.py26def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False):CODE
LOW…sparse_attention/benchmark_triton_block_sparse_fmha.py254def benchmark_topk_sparse_attention():CODE
LOW…/blocksparse_attention/benchmark_library_dense_fmha.py6def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False):CODE
LOW…/blocksparse_attention/benchmark_library_dense_fmha.py18def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False):CODE
LOW…/blocksparse_attention/benchmark_library_dense_fmha.py26def benchmark_topk_sparse_attention():CODE
LOW…/skills/tilelang-semantic/scripts/scan_loop_nesting.py71def _annotations_request_pipeline(node: ast.expr) -> bool:CODE
LOWdocs/programming_guides/cluster_tma.md64def make_tma_multicast_kernel(M, N, block_M, block_N, cluster_mask):CODE
LOWdocs/deeplearning_operators/gemv.md261def splitk_gemv_vectorized_tvm(CODE
LOWdocs/tutorials/debug_tools_for_tilelang.md112def tilelang_callback_cuda_postproc(code, _):CODE
LOWdocs/tutorials/debug_tools_for_tilelang.md141def debug_print_buffer_conditional(M=16, N=16):CODE
LOWdocs/tutorials/debug_tools_for_tilelang.md148def debug_print_value_conditional(M=16, N=16):CODE
LOWdocs/tutorials/debug_tools_for_tilelang.md155def debug_print_register_files(M=16, N=16):CODE
LOWtesting/conftest.py15def _configure_torch_extensions_dir():CODE
LOWtesting/conftest.py54def pytest_collection_modifyitems(config, items):CODE
LOWtesting/python/test_version_provider.py46def test_extracted_sdist_uses_plain_version_by_default(tmp_path: Path, monkeypatch: pytest.MonkeyPatch):CODE
LOWtesting/python/test_version_provider.py56def test_extracted_sdist_can_opt_into_version_label(tmp_path: Path, monkeypatch: pytest.MonkeyPatch):CODE
LOWtesting/python/test_version_provider.py69def test_git_checkout_uses_version_label_by_default(tmp_path: Path, monkeypatch: pytest.MonkeyPatch):CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py323def _compact_copy_view_contract(lane: int, warp_m: int, warp_n: int, k64_word: int):CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py327def _compact_producer_contract(warp_m: int, warp_n: int):CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py331def _compact_package_consumer_byte_offsets(lane: int, warp_m: int, warp_n: int, k64_word: int):CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py335def _cutlass_issue_site_contract(site: int):CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py339def _tilelang_current_issue_site_contract(site: int):CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py259def _pack_semantic_scale_words(scale_bytes):CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py268def _expected_blockscaled_chunk_kmajor_byte_location(row: int, k16_idx: int, k64_cols: int = 4) -> tuple[int, int, int]:CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py303def _sfa_selector_source_lane(lane: int, scale_a_thread_id: int) -> int:CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py307def _sfb_selector_source_lane(lane: int, scale_b_thread_id: int) -> int:CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py353def test_blockscaled_chunk_kmajor_word_offset_fixed_cases():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py381def test_blockscaled_chunk_kmajor_byte_word_and_flat_offsets():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py402def test_blockscaled_chunk_kmajor_explains_compact_source_address_examples():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py427def test_compact_package_producer_contract_inverts_omma_sf_source_lane_selectors():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py459def test_current_register_package_shape_cannot_be_relabelled_as_cute_compact_slots():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py475def test_cutlass_fulltile_issue_site_contract_matches_known_static_dump_points():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py503def test_current_tilelang_issue_order_differs_from_cutlass_serpentine_order():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py513def test_sfa_compact_source_example_spans_warp_m_groups_not_one_consumer_package():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py533def test_sfb_compact_source_example_spans_b_operand_lane_groups():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py553def test_pack_blockscaled_chunk_kmajor_scale_bytes_fixed_byte_offsets():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py592def test_pack_blockscaled_chunk_kmajor_scale_bytes_matches_cutedsl_blocked_sf_layout():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py618def test_pack_blockscaled_chunk_kmajor_scale_bytes_matches_word_swizzle():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py638def test_blockscaled_chunk_kmajor_matches_current_omma_sf_selector_contract():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py683def test_compact_package_issue_table_models_omma_sf_source_lane_selectors():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py746def test_compact_package_issue_table_matches_cpp_macro_issue_order():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py795def test_frontend_package_macro_keeps_compact_selector_issue_order():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py811def test_compact_package_issue_table_matches_effective_row_helpers():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py825def test_compact_package_copy_view_contract_maps_issue_rows_to_kmajor_words():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py869def test_blockscaled_chunk_kmajor_scale_packer_rejects_invalid_shapes():CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py976def test_swizzle_blockscaled_chunk_kmajor_pads_rows_to_full_tiles():CODE
LOW…sting/python/tools/test_tilelang_tools_compile_only.py91def test_compile_kernel_source_default_cpu_c():STRING
LOW…sting/python/tools/test_tilelang_tools_compile_only.py100def test_pass_context_config_enables_line_directives_when_supported():STRING
LOW…sting/python/tools/test_tilelang_tools_compile_only.py108def test_line_directive_parser_reads_file_and_line():STRING
LOW…sting/python/tools/test_tilelang_tools_compile_only.py113def test_line_markers_do_not_collide():STRING
LOW…sting/python/tools/test_tilelang_tools_compile_only.py319def test_resolve_target_rejects_json_auto():STRING
2294 more matches not shown…
Decorative Section Separators463 hits · 1604 pts
SeverityFileLineSnippetContext
MEDIUM…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py39# ---------------------------------------------------------------------------COMMENT
MEDIUM…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py44# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_tcgen05_expand.py133# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_tcgen05_expand.py141# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py59# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py62# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py72# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py74# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py99# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py102# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py123# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py126# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py215# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py218# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py279# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py282# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py462# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py466# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py753# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py756# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py803# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py806# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py822# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py825# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py1007# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py1014# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py1053# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py1058# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py21# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py23# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py318# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py321# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py348# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/layout/test_tilelang_cute.py351# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py28# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py30# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py34# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py36# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py90# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py92# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py102# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py104# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py264# ===================================================================COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py266# ===================================================================COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py211# ===================================================================COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py213# ===================================================================COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py328# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py330# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py456# ===================================================================COMMENT
MEDIUMtesting/python/cuda/test_cuda_f32x2_intrinsics.py458# ===================================================================COMMENT
MEDIUMtesting/python/language/test_tilelang_language_span.py171# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/language/test_tilelang_language_span.py173# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/language/test_tilelang_language_span.py264# ---------------------------------------------------------------------------COMMENT
MEDIUMtesting/python/language/test_tilelang_language_span.py266# ---------------------------------------------------------------------------COMMENT
MEDIUM…sting/python/language/test_tilelang_language_reduce.py422# ---------------------------------------------------------------------------COMMENT
MEDIUM…sting/python/language/test_tilelang_language_reduce.py424# ---------------------------------------------------------------------------COMMENT
MEDIUM…sting/python/language/test_tilelang_language_reduce.py1020# ---------------------------------------------------------------------------COMMENT
MEDIUM…sting/python/language/test_tilelang_language_reduce.py1022# ---------------------------------------------------------------------------COMMENT
MEDIUM…sting/python/language/test_tilelang_language_reduce.py13# ---------------------------------------------------------------------------COMMENT
MEDIUM…sting/python/language/test_tilelang_language_reduce.py15# ---------------------------------------------------------------------------COMMENT
403 more matches not shown…
Unused Imports1041 hits · 910 pts
SeverityFileLineSnippetContext
LOWversion_provider.py1CODE
LOWbenchmark/mamba2/benchmark_mamba_chunk_scan.py4CODE
LOWcmake/generate_windows_import_lib.py1CODE
LOWcmake/find_pip_cuda.py13CODE
LOWcmake/ccache_strip_pep517.py27CODE
LOW…/skills/tilelang-semantic/scripts/scan_loop_nesting.py4CODE
LOWtesting/python/test_version_provider.py1CODE
LOWtesting/python/tools/test_tilelang_tools_cuda_iket.py1CODE
LOWtesting/python/cache/test_tilelang_cuda_binary_cache.py1CODE
LOWtesting/python/metal/test_metal_codegen.py2CODE
LOWtesting/python/metal/test_metal_gemm_v2.py8CODE
LOWtesting/python/target/test_tilelang_target.py1CODE
LOWtesting/python/target/test_tilelang_rocm_target.py5CODE
LOW…ng/python/language/test_tilelang_language_tma_store.py12CODE
LOW…sting/python/language/test_tilelang_language_unroll.py3CODE
LOW…/language/test_tilelang_language_tma_gather_scatter.py5CODE
LOWtesting/python/language/test_tilelang_language_scan.py1CODE
LOWtesting/python/language/test_tilelang_language_ptr.py3CODE
LOWtesting/python/language/test_tilelang_language_let.py2CODE
LOW…ing/python/language/test_tilelang_language_pipeline.py1CODE
LOWtesting/python/backend/test_tilelang_backend_module.py1CODE
LOWtesting/python/amd/test_tilelang_test_amd.py2CODE
LOW…sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py5CODE
LOWtesting/python/amd/test_tilelang_gemm_mfma_intrinsic.py4CODE
LOWtesting/python/jit/test_tilelang_jit_tvm_ffi.py1CODE
LOWtesting/python/jit/test_tilelang_jit_cython.py1CODE
LOWtesting/python/jit/test_tilelang_jit_nvrtc.py1CODE
LOWtesting/python/jit/test_tilelang_jit_nullptr.py2CODE
LOWtesting/python/jit/test_tilelang_jit_cutedsl.py1CODE
LOWtesting/python/jit/test_tilelang_jit_gemm_cython.py1CODE
LOWtesting/python/kernel/test_tilelang_kernel_gemv_simt.py4CODE
LOWtesting/python/kernel/test_tilelang_kernel_gemm_simt.py4CODE
LOWtesting/python/kernel/test_tilelang_kernel_gemm.py1CODE
LOW…ing/python/kernel/test_tilelang_kernel_gemm_batched.py1CODE
LOWtesting/python/debug/test_pass_events.py3CODE
LOWexamples/kda/chunk_delta_h_fwd.py3CODE
LOWexamples/kda/chunk_bwd_dv.py4CODE
LOWexamples/kda/wy_fast_bwd.py3CODE
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py359CODE
LOW…tion/example_triton_sparse_gqa_decode_varlen_indice.py11CODE
LOW…tion/example_triton_sparse_gqa_decode_varlen_indice.py396CODE
LOW…ention/example_triton_sparse_gqa_decode_varlen_mask.py390CODE
LOW…_attention/example_tilelang_sparse_gqa_decode_paged.py451CODE
LOWexamples/linear_attention/example_mamba_chunk_scan.py4CODE
LOWexamples/linear_attention/example_mamba_chunk_state.py5CODE
LOWexamples/deepseek_v32/utils.py6CODE
LOWexamples/deepseek_v32/utils.py7CODE
LOWexamples/deepseek_v32/utils.py8CODE
LOWexamples/deepseek_v32/utils.py10CODE
LOWexamples/deepseek_v32/utils.py12CODE
LOWexamples/deepseek_v32/utils.py13CODE
LOWexamples/deepseek_v32/utils.py14CODE
LOWexamples/deepseek_v32/utils.py15CODE
LOWexamples/deepseek_v32/utils.py16CODE
LOWexamples/deepseek_v32/utils.py17CODE
LOWexamples/deepseek_v32/utils.py19CODE
LOWexamples/gemm/example_gemm_intrinsics.py1CODE
LOWexamples/gdn/example_cumsum.py6CODE
LOWexamples/gdn/example_chunk_delta_h.py3CODE
LOWexamples/gdn/example_chunk_delta_h.py23CODE
981 more matches not shown…
Deep Nesting532 hits · 506 pts
SeverityFileLineSnippetContext
LOWversion_provider.py44CODE
LOWbenchmark/matmul/benchmark_matmul.py33CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py143CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py638CODE
LOW…/quantize/test_tilelang_quantize_nvfp4_scale_layout.py811CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py47CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py102CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py298CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py314CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py407CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py49CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py113CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py300CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py316CODE
LOW…g/python/analysis/test_tilelang_nested_loop_checker.py425CODE
LOWtesting/python/metal/test_metal_codegen.py9CODE
LOWtesting/python/metal/test_metal_codegen.py11CODE
LOWtesting/python/metal/test_metal_codegen_linux.py13CODE
LOWtesting/python/metal/test_metal_codegen_linux.py15CODE
LOWtesting/python/cpu/test_tilelang_cpu_reduce.py50CODE
LOWtesting/python/cpu/test_tilelang_cpu_reduce.py95CODE
LOWtesting/python/cpu/test_tilelang_cpu_reduce.py105CODE
LOWtesting/python/cpu/test_tilelang_cpu_gemm.py61CODE
LOWtesting/python/cpu/test_tilelang_cpu_gemm.py62CODE
LOWtesting/python/cpu/test_tilelang_cpu_gemm.py65CODE
LOWtesting/python/llvm/test_tilelang_llvm_gemm.py63CODE
LOWtesting/python/llvm/test_tilelang_llvm_gemm.py64CODE
LOWtesting/python/llvm/test_tilelang_llvm_gemm.py67CODE
LOW…/python/language/test_tilelang_language_warp_reduce.py10CODE
LOW…/python/language/test_tilelang_language_warp_reduce.py96CODE
LOW…/python/language/test_tilelang_language_warp_reduce.py14CODE
LOW…/python/language/test_tilelang_language_warp_reduce.py97CODE
LOW…sting/python/language/test_tilelang_language_reduce.py49CODE
LOW…sting/python/language/test_tilelang_language_reduce.py671CODE
LOW…sting/python/language/test_tilelang_language_reduce.py673CODE
LOW…sting/python/language/test_tilelang_language_all_of.py7CODE
LOW…ing/python/language/test_tilelang_language_atom_mma.py48CODE
LOW…ing/python/language/test_tilelang_language_atom_mma.py142CODE
LOW…ing/python/language/test_tilelang_language_atom_mma.py246CODE
LOW…ing/python/language/test_tilelang_language_atom_mma.py82CODE
LOW…ing/python/language/test_tilelang_language_atom_mma.py169CODE
LOW…ing/python/language/test_tilelang_language_atom_mma.py269CODE
LOW…sting/python/language/test_tilelang_language_any_of.py7CODE
LOW…ing/python/language/test_tilelang_language_pipeline.py157CODE
LOW…ing/python/language/test_tilelang_language_pipeline.py181CODE
LOW…anguage/test_tilelang_language_nvf4_mma_block_scale.py259CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py612CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1076CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1139CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1173CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1211CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1298CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1080CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1145CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1180CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1223CODE
LOW…g/python/language/test_tilelang_language_reducer_v2.py1307CODE
LOWtesting/python/math/test_math_ieee_math.py40CODE
LOWtesting/python/arith/test_arith_intset.py139CODE
LOW…sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py16CODE
472 more matches not shown…
Cross-File Repetition99 hits · 495 pts
SeverityFileLineSnippetContext
HIGHbenchmark/matmul_fp8/benchmark_matmul.py0a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matriSTRING
HIGHbenchmark/matmul/benchmark_matmul.py0a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matriSTRING
HIGHbenchmark/matmul/benchmark_matmul_sp.py0a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matriSTRING
HIGHtesting/python/autotune/test_tilelang_autotune.py0a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matriSTRING
HIGH…g/python/autotune/test_tilelang_autotune_eager_mode.py0a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matriSTRING
HIGH…/python/autotune/test_tilelang_autotune_with_inputs.py0a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matriSTRING
HIGHbenchmark/matmul_fp8/benchmark_matmul.py0generate a list of configuration dictionaries that will be used for tuning. parameters ---------- with_roller : bool wheSTRING
HIGHbenchmark/matmul/benchmark_matmul.py0generate a list of configuration dictionaries that will be used for tuning. parameters ---------- with_roller : bool wheSTRING
HIGHbenchmark/matmul/benchmark_matmul_sp.py0generate a list of configuration dictionaries that will be used for tuning. parameters ---------- with_roller : bool wheSTRING
HIGHbenchmark/matmul_fp8/benchmark_matmul.py0create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters -STRING
HIGHbenchmark/matmul/benchmark_matmul.py0create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters -STRING
HIGHtesting/python/autotune/test_tilelang_autotune.py0create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters -STRING
HIGHbenchmark/matmul/benchmark_matmul_sp.py0create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters -STRING
HIGHbenchmark/matmul_fp8/benchmark_matmul.py0the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of shaSTRING
HIGHbenchmark/matmul/benchmark_matmul.py0the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of shaSTRING
HIGHbenchmark/matmul/benchmark_matmul_sp.py0the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of shaSTRING
HIGHtesting/python/autotune/test_tilelang_autotune.py0the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of shaSTRING
HIGH…/python/autotune/test_tilelang_autotune_with_inputs.py0the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of shaSTRING
HIGHexamples/kda/FLA_KDA/fla_utils.py0a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output ofSTRING
HIGHexamples/deepseek_v32/utils.py0a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output ofSTRING
HIGHexamples/dsa_hisa/tilelang_utils.py0a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output ofSTRING
HIGHexamples/dsa_sparse_finetune/index.py0a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output ofSTRING
HIGHexamples/plot_layout/fragment_mma_load_a.py0given the row index `i` and column index `j` in the fragment,STRING
HIGHexamples/plot_layout/fragment_mfma_load_a.py0given the row index `i` and column index `j` in the fragment,STRING
HIGH…lelang/cuda/intrinsics/macro/mma_sp_macro_generator.py0given the row index `i` and column index `j` in the fragment,STRING
HIGHtilelang/cuda/intrinsics/macro/mma_macro_generator.py0given the row index `i` and column index `j` in the fragment,STRING
HIGH…lang/cuda/intrinsics/macro/mma_sm70_macro_generator.py0given the row index `i` and column index `j` in the fragment,STRING
HIGHtilelang/cuda/intrinsics/macro/wgmma_macro_generator.py0given the row index `i` and column index `j` in the fragment,STRING
HIGHtilelang/rocm/intrinsics/mfma_macro_generator.py0given the row index `i` and column index `j` in the fragment,STRING
HIGHexamples/deepseek_v32/utils.py0calculate similarity between two tensors using a normalized dot product metric. unlike torch.testing.assert_close which STRING
HIGHexamples/dsa_hisa/tilelang_utils.py0calculate similarity between two tensors using a normalized dot product metric. unlike torch.testing.assert_close which STRING
HIGHexamples/dsa_sparse_finetune/utils.py0calculate similarity between two tensors using a normalized dot product metric. unlike torch.testing.assert_close which STRING
HIGHexamples/deepseek_v32/utils.py0assert that two tensors are similar using a global similarity metric. key differences from torch.testing.assert_close: -STRING
HIGHexamples/dsa_hisa/tilelang_utils.py0assert that two tensors are similar using a global similarity metric. key differences from torch.testing.assert_close: -STRING
HIGHexamples/dsa_sparse_finetune/utils.py0assert that two tensors are similar using a global similarity metric. key differences from torch.testing.assert_close: -STRING
HIGH…nel_benchmark/tilelang_bitnet_158_int8xint2_prefill.py0template <typename t1, typename t2> __device__ void decode_i2s_to_i8s(t1 *_i2b, t2 *_i8s, const int n = 16) { // convertSTRING
HIGH…rnel_benchmark/tilelang_bitnet_158_int8xint2_decode.py0template <typename t1, typename t2> __device__ void decode_i2s_to_i8s(t1 *_i2b, t2 *_i8s, const int n = 16) { // convertSTRING
HIGHexamples/dequantize_gemm/quantize/lop3.py0template <typename t1, typename t2> __device__ void decode_i2s_to_i8s(t1 *_i2b, t2 *_i8s, const int n = 16) { // convertSTRING
HIGH…es/warp_specialize/example_warp_specialize_flashmla.py0# inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_STRING
HIGHexamples/deepseek_mla/example_mla_decode_persistent.py0# inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_STRING
HIGHexamples/deepseek_mla/example_mla_decode_ws.py0# inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_STRING
HIGH…/deepseek_mla/amd/benchmark_mla_decode_amd_tilelang.py0# inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_STRING
HIGHexamples/deepseek_nsa/example_tilelang_nsa_bwd.py0args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): kSTRING
HIGHexamples/deepseek_nsa/example_triton_nsa_fwd.py0args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): kSTRING
HIGH…amples/deepseek_nsa/example_tilelang_nsa_fwd_varlen.py0args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): kSTRING
HIGHexamples/deepseek_nsa/example_triton_nsa_bwd.py0args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): kSTRING
HIGHexamples/deepseek_nsa/example_triton_nsa_fwd_varlen.py0args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): kSTRING
HIGHexamples/deepseek_nsa/benchmark/benchmark_nsa_fwd.py0args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): kSTRING
HIGHexamples/deepseek_nsa/reference.py0args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): kSTRING
HIGHtilelang/cuda/op/gemm/gemm_mma_sm70.py0the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core STRING
HIGHtilelang/cuda/op/gemm/gemm_mma.py0the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core STRING
HIGHtilelang/cuda/op/gemm/gemm_wgmma.py0the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core STRING
HIGHtilelang/cuda/op/gemm_sp/gemm_sp_mma.py0the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core STRING
HIGHtilelang/cuda/op/gemm_sp/gemm_sp_wgmma.py0the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core STRING
HIGH…lelang/cuda/intrinsics/macro/mma_sp_macro_generator.py0is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_warSTRING
HIGHtilelang/cuda/intrinsics/macro/mma_macro_generator.py0is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_warSTRING
HIGH…lang/cuda/intrinsics/macro/mma_sm70_macro_generator.py0is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_warSTRING
HIGHtilelang/rocm/intrinsics/mfma_macro_generator.py0is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_warSTRING
HIGH…lelang/cuda/intrinsics/macro/mma_sp_macro_generator.py0create a layout function for storing mma results into a fragment buffer. this layout is used in conjunction with `inversSTRING
HIGH…lang/cuda/intrinsics/macro/wgmma_sp_macro_generator.py0create a layout function for storing mma results into a fragment buffer. this layout is used in conjunction with `inversSTRING
39 more matches not shown…
Cross-Language Confusion86 hits · 381 pts
SeverityFileLineSnippetContext
HIGH…hon/transform/test_tilelang_transform_lower_tile_op.py418 the old code would leave `v_thread >= 0 && v_thread < 1` in theSTRING
HIGHtesting/python/transform/test_nullable_buffer_params.py109 - Another (non-null) tensor argument exists, but does not mention `m`STRING
HIGHexamples/dequantize_gemm/quantize/lop3.py720 if constexpr (withZeros && ZerosKind == 0)CODE
HIGHexamples/dequantize_gemm/quantize/lop3.py728 if constexpr (withZeros && ZerosKind == 1)CODE
HIGHtilelang/tools/lower_trace/html.py905 var firstVisible = null;CODE
HIGHtilelang/tools/lower_trace/html.py909 if (!_activeFilter || status === _activeFilter) {CODE
HIGHtilelang/tools/lower_trace/html.py919 if (!activeLink || activeLink.classList.contains('filtered-out')) {CODE
HIGHtilelang/tools/lower_trace/html.py1016 var limit = (evt && evt.altKey) ? 999999 : n;CODE
HIGHtilelang/tools/lower_trace/html.py1019 while (r && shown < limit) {CODE
HIGHtilelang/tools/lower_trace/html.py1026 while (r && shown < limit) {CODE
HIGHtilelang/tools/lower_trace/html.py1036 var table = section ? section.querySelector('table') : null;CODE
HIGHtilelang/tools/lower_trace/html.py1044 var table = section ? section.querySelector('table') : null;CODE
HIGHtilelang/tools/lower_trace/html.py1085var _alignMode = null;CODE
HIGHtilelang/tools/lower_trace/html.py1086var _pendingLeft = null;CODE
HIGHtilelang/tools/lower_trace/html.py1087var _alignStatus = null;CODE
HIGHtilelang/tools/lower_trace/html.py1097 _pendingLeft = null;CODE
HIGHtilelang/tools/lower_trace/html.py1098 _alignMode = null;CODE
HIGHtilelang/tools/lower_trace/html.py1145 while (i < m && j < n) {CODE
HIGHtilelang/tools/lower_trace/html.py1148 while (i < m && j < n && a[i] === b[j]) { i++; j++; }CODE
HIGHtilelang/tools/lower_trace/html.py1149 blocks.push([si, sj, i - si]);CODE
HIGHtilelang/tools/lower_trace/html.py1155 if (si > ai || sj > bi) {CODE
HIGHtilelang/tools/lower_trace/html.py1156 var tag = (si > ai && sj > bi) ? 'replace' : (si > ai ? 'delete' : 'insert');CODE
HIGHtilelang/tools/lower_trace/html.py1157 ops.push({ tag: tag, i1: ai + aOff, i2: si + aOff, j1: bi + bOff, j2: sj + bOff });CODE
HIGHtilelang/tools/lower_trace/html.py1159 ops.push({ tag: 'equal', i1: si + aOff, i2: si + size + aOff, j1: sj + bOff, j2: sj + size + bOff });CODE
HIGHtilelang/tools/lower_trace/html.py1162 if (ai < m || bi < n) {CODE
HIGHtilelang/tools/lower_trace/html.py1163 var tag = (ai < m && bi < n) ? 'replace' : (ai < m ? 'delete' : 'insert');CODE
HIGHtilelang/tools/lower_trace/html.py1164 ops.push({ tag: tag, i1: ai + aOff, i2: m + aOff, j1: bi + bOff, j2: n + bOff });CODE
HIGHtilelang/tools/lower_trace/html.py1177 rows.push('<tr>' +CODE
HIGHtilelang/tools/lower_trace/html.py1187 for (var x = op.i1; x < op.i2; x++) bStripped.push((beforeLines[x]||'').trim());CODE
HIGHtilelang/tools/lower_trace/html.py1188 for (var y = op.j1; y < op.j2; y++) aStripped.push((afterLines[y]||'').trim());CODE
HIGHtilelang/tools/lower_trace/html.py1194 for (var t = 0; t < so.i2 - so.i1; t++) matched.push([so.i1 + t, so.j1 + t]);CODE
HIGHtilelang/tools/lower_trace/html.py1200 for (var k = op.i1; k < op.i2; k++) { if (!mL[k]) unmatchedL.push(k); }CODE
HIGHtilelang/tools/lower_trace/html.py1201 for (var k = op.j1; k < op.j2; k++) { if (!mR[k]) unmatchedR.push(k); }CODE
HIGHtilelang/tools/lower_trace/html.py1206 if (k < gl.length && k < gr.length) all.push([gl[k], gr[k], false]);CODE
HIGHtilelang/tools/lower_trace/html.py1206 if (k < gl.length && k < gr.length) all.push([gl[k], gr[k], false]);CODE
HIGHtilelang/tools/lower_trace/html.py1207 else if (k < gl.length) all.push([gl[k], null, false]);CODE
HIGHtilelang/tools/lower_trace/html.py1207 else if (k < gl.length) all.push([gl[k], null, false]);CODE
HIGHtilelang/tools/lower_trace/html.py1208 else all.push([null, gr[k], false]);CODE
HIGHtilelang/tools/lower_trace/html.py1208 else all.push([null, gr[k], false]);CODE
HIGHtilelang/tools/lower_trace/html.py1214 while (up < unmatchedL.length && unmatchedL[up] < li) { gl.push(unmatchedL[up]); up++; }CODE
HIGHtilelang/tools/lower_trace/html.py1214 while (up < unmatchedL.length && unmatchedL[up] < li) { gl.push(unmatchedL[up]); up++; }CODE
HIGHtilelang/tools/lower_trace/html.py1215 while (vp < unmatchedR.length && unmatchedR[vp] < ri) { gr.push(unmatchedR[vp]); vp++; }CODE
HIGHtilelang/tools/lower_trace/html.py1215 while (vp < unmatchedR.length && unmatchedR[vp] < ri) { gr.push(unmatchedR[vp]); vp++; }CODE
HIGHtilelang/tools/lower_trace/html.py1217 all.push([li, ri, true]);CODE
HIGHtilelang/tools/lower_trace/html.py1222 var isPinned = (li === pinL && ri === pinR);CODE
HIGHtilelang/tools/lower_trace/html.py1223 if (li !== null && ri !== null) {CODE
HIGHtilelang/tools/lower_trace/html.py1223 if (li !== null && ri !== null) {CODE
HIGHtilelang/tools/lower_trace/html.py1225 if (diff.isWsOnly && matched) {CODE
HIGHtilelang/tools/lower_trace/html.py1227 rows.push('<tr' + cls + '>' +CODE
HIGHtilelang/tools/lower_trace/html.py1234 rows.push('<tr' + cls + '>' +CODE
HIGHtilelang/tools/lower_trace/html.py1240 } else if (li !== null) {CODE
HIGHtilelang/tools/lower_trace/html.py1241 rows.push('<tr>' +CODE
HIGHtilelang/tools/lower_trace/html.py1246 rows.push('<tr>' +CODE
HIGHtilelang/tools/lower_trace/html.py1254 rows.push('<tr>' +CODE
HIGHtilelang/tools/lower_trace/html.py1261 rows.push('<tr>' +CODE
HIGHtilelang/tools/lower_trace/html.py1286 while (i < m && j < n) {CODE
HIGHtilelang/tools/lower_trace/html.py1288 left.push(escHtml(before[i]));CODE
HIGHtilelang/tools/lower_trace/html.py1289 right.push(escHtml(after[j]));CODE
HIGHtilelang/tools/lower_trace/html.py1298 left.push('<span class="del-word">' + escHtml(chunk) + '</span>');CODE
HIGHtilelang/tools/lower_trace/html.py1302 while (j < n && (i >= m || sm[i][j+1] > sm[i+1][j]) && before[i] !== after[j]) {CODE
26 more matches not shown…
Over-Commented Block282 hits · 248 pts
SeverityFileLineSnippetContext
LOWCMakeLists.txt1# Learn a lot from the MLC - LLM ProjectCOMMENT
LOWCMakeLists.txt21project(TILE_LANG C CXX)COMMENT
LOWCMakeLists.txt41 set(CMAKE_POLICY_DEFAULT_CMP0141 NEW)COMMENT
LOWCMakeLists.txt61 # Apply /EHsc and /bigobj globally so every MSVC-compatible target picksCOMMENT
LOWCMakeLists.txt201 # so cache would work without setting `base_dir`.COMMENT
LOWformat.sh1#!/usr/bin/env bashCOMMENT
LOWdocs/get_started/Installation.md261# Clone + build TileLang (ROCm)COMMENT
LOWtesting/python/cache/test_tilelang_kernel_cache.py1# Test Plan: Disk Cache Verification using PostProc CallbackCOMMENT
LOWtesting/python/layout/test_tilelang_tcgen05_expand.py1# Pin ExpandTcgen05Layout against the CUTLASS Copy_Traits ground truth.COMMENT
LOWtesting/python/layout/test_tilelang_tcgen05_expand.py121def test_expand_gapped_tile_issues_per_batch():COMMENT
LOW…on/layout/test_tilelang_layout_inference_z3_context.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOW…ng/python/language/test_tilelang_language_tmem_copy.py21COMMENT
LOW…/python/language/test_tilelang_language_frontend_v2.py61# with T.Kernel(128, 128) as (bx, by):COMMENT
LOW…/python/language/test_tilelang_language_frontend_v2.py81# var_20: T.float8_e8m0fnu = 1.0COMMENT
LOW…/python/language/test_tilelang_language_frontend_v2.py101# var_16: T.float8_e4m3fn = var_16COMMENT
LOW…/python/language/test_tilelang_language_frontend_v2.py141 buf_22 = T.alloc_buffer((1,), dtype=T.bfloat16, scope="shared") # noqa F841COMMENT
LOW…/python/language/test_tilelang_language_frontend_v2.py161# T.uint16,COMMENT
LOW…/python/language/test_tilelang_language_frontend_v2.py181# torch.long,COMMENT
LOWtesting/python/arith/test_arith_simplify.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtesting/python/arith/test_arith_iter_affine_map.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtesting/python/arith/test_arith_intset.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtesting/python/amd/test_tilelang_test_amd.py241COMMENT
LOWtesting/python/amd/test_tilelang_hip_codegen.py161 torch.cuda.synchronize()COMMENT
LOWtesting/python/amd/test_tilelang_hip_codegen.py261# T.alloc_var(init=<literal>) initialisation on HIP;COMMENT
LOWtesting/python/amd/test_tilelang_hip_codegen.py661 assert "this_grid().sync()" in src, f"T.sync_grid() should generate 'this_grid().sync()' but not found:\n{src}"COMMENT
LOWtesting/python/amd/test_tilelang_hip_codegen.py781#COMMENT
LOW…ython/transform/test_tilelang_transform_thread_sync.py821 S[tx] = T.float32(1)COMMENT
LOW…n/transform/test_tilelang_transform_make_packed_api.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWexamples/aws/gemm.py41 C_tmem = T.alloc_tmem([block_M, block_N], accum_dtype)COMMENT
LOWexamples/aws/gemm.py81 # A scope is a scheduled loop: a serial loop named by itsCOMMENT
LOWexamples/aws/gemm.py101 "copy_B_g2s",COMMENT
LOWexamples/aws/flash_attention.py81 # after row-max and publishing P before the row-sum.COMMENT
LOWexamples/bitnet-1.58b/configuration_bitnet.py1# coding=utf-8COMMENT
LOWexamples/bitnet-1.58b/modeling_bitnet.py1# coding=utf-8COMMENT
LOWexamples/bitnet-1.58b/tokenization_bitnet.py1# coding=utf-8COMMENT
LOWexamples/dequantize_gemm/quantize/quantization.py1# Copyright 2018 The apache/tvm Authors. All Rights Reserved.COMMENT
LOWexamples/dequantize_gemm/quantize/mxfp.py41 for (int j = 0; j < 4; ++j) {COMMENT
LOWexamples/dequantize_gemm/quantize/mxfp.py61# AMD gfx950 / HIP version of fp4->bf16 twiddling dequantization.COMMENT
LOW…/deepseek_mla/amd/benchmark_mla_decode_amd_tilelang.py201 else:COMMENT
LOWtilelang/env.py101 # tvm-ffi's Cython layer defaults to ``Py_BEGIN_ALLOW_THREADS`` around everyCOMMENT
LOWtilelang/tools/pass_visualizer/__init__.py21# NOTE: viewer (build_pass_data / emit_html / emit_txt) is intentionally NOTCOMMENT
LOWtilelang/cuda/pipeline.py81 mod = tilelang.transform.LegalizeNegativeIndex()(mod)COMMENT
LOWtilelang/cuda/pipeline.py101 # Tile-level warp specialization: runs before layout inference so thatCOMMENT
LOWtilelang/cuda/pipeline.py141 # Assert no reducer v2 construct survived materializationCOMMENT
LOWtilelang/cuda/pipeline.py221 # TODO(lei): This is a hack to make sure theCOMMENT
LOWtilelang/cuda/intrinsics/layout/mma_layout.py301 swizzle_bytes = min(128, row_bytes)COMMENT
LOWtilelang/cuda/intrinsics/macro/wgmma_macro_generator.py101 operand or the atom-level API.COMMENT
LOWtilelang/language/tir/ir.py321# Upstream ``tvm.tir.generic.cast`` only takes a generic ``annotations`` mapCOMMENT
LOWtilelang/language/parser/__init__.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtilelang/language/parser/operation.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtilelang/language/parser/operation.py121 # doc.Div <-- is overloadedCOMMENT
LOWtilelang/language/parser/parser.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtilelang/language/parser/entry.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtilelang/language/ast/_ffi_api.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtilelang/language/ast/__init__.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtilelang/language/ast/ir.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
LOWtilelang/language/eager/builder.py561 else:COMMENT
LOWtilelang/language/eager/builder.py1001 # def foo():COMMENT
LOWtilelang/language/eager/ast.py401 # for example:COMMENT
LOWtilelang/contrib/rocm.py1# Licensed to the Apache Software Foundation (ASF) under oneCOMMENT
222 more matches not shown…
Excessive Try-Catch Wrapping163 hits · 184 pts
SeverityFileLineSnippetContext
LOWbenchmark/matmul_metal/benchmark_matmul_metal.py247 except Exception as e:CODE
LOWcmake/find_pip_cuda.py173 except Exception:CODE
LOWtesting/python/math/test_math_ieee_math.py161 except Exception as e:CODE
LOWtesting/python/arith/test_arith_hard.py101 except Exception as e:CODE
LOW…/test_tilelang_transform_pipeline_barrier_ownership.py23 except Exception:CODE
LOWexamples/kda/FLA_KDA/fla_utils.py140 except Exception:CODE
LOWexamples/kda/FLA_KDA/fla_utils.py149 except Exception:CODE
LOWexamples/kda/FLA_KDA/fla_utils.py239 except Exception:CODE
MEDIUMexamples/kda/FLA_KDA/fla_utils.py224def get_all_max_shared_mem():CODE
LOWexamples/autodd/tilelang_buggy.py220 except Exception as e:CODE
MEDIUMexamples/autodd/tilelang_buggy.py221 print(f"Error: {e}")CODE
LOWexamples/autodd/tilelang_minimized_expected.py51 except Exception as e:CODE
MEDIUMexamples/amd/example_amd_flash_attn_bwd.py19 print("Error: GPU Device is not detected")CODE
MEDIUMexamples/amd/example_amd_flash_attn_fwd.py17 print("Error: GPU Device is not detected")CODE
LOWexamples/gdn/example_cumsum.py136 except Exception as e:CODE
LOWexamples/gdn/example_chunk_delta_h.py321 except Exception as e:CODE
LOWexamples/gdn/example_chunk_delta_h.py336 except Exception as e:CODE
LOWexamples/gdn/example_chunk_delta_h.py345 except Exception as e:CODE
LOWexamples/gdn/example_chunk_o.py208 except Exception as e:CODE
LOWexamples/gdn/example_wy_fast.py184 except Exception as e:CODE
LOWexamples/gdn/example_wy_fast.py190 except Exception as e:CODE
LOWexamples/gdn/example_chunk_o_bwd.py438 except Exception as e:CODE
LOWexamples/gdn/example_chunk_o_bwd.py445 except Exception as e:CODE
LOWexamples/gdn/example_chunk_o_bwd.py453 except Exception as e:CODE
LOWexamples/gdn/example_chunk_o_bwd.py461 except Exception as e:CODE
LOWexamples/gdn/example_chunk_scaled_dot_kkt.py164 except Exception as e:CODE
LOWexamples/gdn/example_chunk_delta_bwd.py360 except Exception as e:CODE
LOWexamples/gdn/example_chunk_delta_bwd.py366 except Exception as e:CODE
LOWexamples/gdn/example_chunk_delta_bwd.py372 except Exception as e:CODE
MEDIUMexamples/gdn/example_chunk_delta_bwd.py356def test_result(dh_0, dh0_0, dv2_0, dh_1, dh0_1, dv2_1, name):CODE
LOWexamples/bitnet-1.58b/vllm_workspace/conftest.py207 except Exception:CODE
LOWtilelang/env.py595 except Exception:CODE
LOWtilelang/__init__.py27 except Exception:CODE
LOWtilelang/__init__.py30 except Exception:CODE
LOWtilelang/__init__.py38 except Exception as exc:CODE
LOWtilelang/__init__.py86 except Exception:CODE
LOWtilelang/__init__.py122 except Exception:CODE
LOWtilelang/autodd.py642 except Exception as _:CODE
LOWtilelang/autodd.py702 except Exception as _:CODE
LOWtilelang/autodd.py760 except Exception:CODE
LOWtilelang/autodd.py766 except Exception as e:CODE
LOWtilelang/autodd.py813 except Exception as e:CODE
LOWtilelang/errors.py70 except Exception:CODE
LOWtilelang/tools/pass_timing.py60 except Exception:CODE
LOWtilelang/tools/compile_only.py51 except Exception:CODE
LOWtilelang/tools/compile_only.py249 except Exception as exc:CODE
LOWtilelang/tools/cuda/iket/session.py131 except Exception:CODE
LOWtilelang/tools/lower_trace/__init__.py112 except Exception as e:CODE
LOWtilelang/tools/lower_trace/__init__.py179 except Exception as exc:CODE
LOWtilelang/tools/lower_trace/__init__.py208 except Exception:CODE
LOWtilelang/tools/lower_trace/core.py156 except Exception:CODE
LOWtilelang/tools/lower_trace/core.py193 except Exception:CODE
LOWtilelang/tools/lower_trace/core.py286 except Exception as exc:CODE
LOWtilelang/tools/lower_trace/core.py339 except Exception as error:CODE
LOWtilelang/tools/lower_trace/core.py422 except Exception as exc:CODE
LOWtilelang/tools/lower_trace/core.py438 except Exception as error:CODE
LOWtilelang/tools/lower_trace/core.py486 except Exception as exc:CODE
LOWtilelang/analysis/ast_printer.py66 except Exception as e:CODE
LOWtilelang/cache/kernel_cache.py747 except Exception:CODE
LOWtilelang/cache/kernel_cache.py107 except Exception:CODE
103 more matches not shown…
AI Structural Patterns148 hits · 142 pts
SeverityFileLineSnippetContext
LOWbenchmark/matmul_fp8/benchmark_matmul.py119CODE
LOWtesting/python/language/test_tilelang_language_clamp.py47CODE
LOWtesting/python/language/test_tilelang_language_clamp.py102CODE
LOWtesting/python/math/test_math_ieee_math.py40CODE
LOW…sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py16CODE
LOW…sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py270CODE
LOW…_tilelang_transform_producer_consumer_ws_persistent.py34CODE
LOW…_tilelang_transform_producer_consumer_ws_persistent.py74CODE
LOW…_tilelang_transform_producer_consumer_ws_persistent.py114CODE
LOW…_tilelang_transform_producer_consumer_ws_persistent.py204CODE
LOW…_tilelang_transform_producer_consumer_ws_persistent.py257CODE
LOW…_tilelang_transform_producer_consumer_ws_persistent.py350CODE
LOW…/python/carver/test_tilelang_carver_recommend_hints.py105CODE
LOWexamples/kda/chunk_delta_h_fwd.py185CODE
LOWexamples/kda/chunk_bwd_dqkwg.py186CODE
LOWexamples/kda/FLA_KDA/fla_chunk_delta.py470CODE
LOWexamples/kda/FLA_KDA/fla_chunk_delta.py524CODE
LOWexamples/attention_sink/example_gqa_sink_bwd_varlen.py670CODE
LOWexamples/attention_sink/example_gqa_sink_bwd_bhsd.py26CODE
LOWexamples/attention_sink/example_mha_sink_fwd_bhsd.py191CODE
LOWexamples/attention_sink/example_gqa_sink_fwd_varlen.py299CODE
LOWexamples/attention_sink/benchmark_mha_sink_fwd.py125CODE
LOWexamples/attention_sink/benchmark_gqa_sink_fwd.py128CODE
LOWexamples/deepseek_mhc/example_mhc_pre.py406CODE
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py254CODE
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py289CODE
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py300CODE
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py314CODE
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py384CODE
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py200CODE
LOW…tion/example_triton_sparse_gqa_decode_varlen_indice.py307CODE
LOW…tion/example_triton_sparse_gqa_decode_varlen_indice.py318CODE
LOW…tion/example_triton_sparse_gqa_decode_varlen_indice.py321CODE
LOW…ention/example_triton_sparse_gqa_decode_varlen_mask.py303CODE
LOW…ention/example_triton_sparse_gqa_decode_varlen_mask.py314CODE
LOW…ention/example_triton_sparse_gqa_decode_varlen_mask.py317CODE
LOW…on/example_tilelang_sparse_gqa_decode_varlen_indice.py264CODE
LOW…on/example_tilelang_sparse_gqa_decode_varlen_indice.py298CODE
LOW…on/example_tilelang_sparse_gqa_decode_varlen_indice.py309CODE
LOW…on/example_tilelang_sparse_gqa_decode_varlen_indice.py323CODE
LOW…on/example_tilelang_sparse_gqa_decode_varlen_indice.py375CODE
LOW…on/example_tilelang_sparse_gqa_decode_varlen_indice.py208CODE
LOW…_attention/example_tilelang_sparse_gqa_decode_paged.py305CODE
LOW…_attention/example_tilelang_sparse_gqa_decode_paged.py316CODE
LOW…_attention/example_tilelang_sparse_gqa_decode_paged.py222CODE
LOWexamples/deepseek_v32/sparse_mla_bwd.py77CODE
LOWexamples/deepseek_v32/sparse_mla_bwd.py289CODE
LOWexamples/deepseek_v32/sparse_mla_bwd.py335CODE
LOWexamples/deepseek_v32/sparse_mla_fwd_seesaw.py537CODE
LOWexamples/deepseek_v32/sparse_mla_fwd_pipelined.py342CODE
LOWexamples/deepseek_v32/sparse_mla_fwd_pipelined.py388CODE
LOWexamples/deepseek_v32/sparse_mla_fwd.py228CODE
LOWexamples/deepseek_v32/sparse_mla_fwd.py273CODE
LOWexamples/gemm_int4/example_tilelang_gemm_int4.py41CODE
LOWexamples/gemm/example_gemm_advanced_autotune.py118CODE
LOWexamples/gemm/example_gemm_advanced_autotune.py275CODE
LOWexamples/amd/example_amd_flash_attn_fwd.py52CODE
LOWexamples/gdn/example_cumsum.py24CODE
LOWexamples/gdn/example_chunk_delta_h.py228CODE
LOWexamples/gdn/example_chunk_scaled_dot_kkt.py53CODE
88 more matches not shown…
Docstring Block Structure28 hits · 140 pts
SeverityFileLineSnippetContext
HIGHexamples/deepseek_v32/inference/model.py114 Forward pass for parallel embedding layer. Args: x (torch.Tensor): Input tensor containingSTRING
HIGHexamples/deepseek_v32/inference/model.py141 Applies a linear transformation to the incoming data: y = xA^T + b. This function supports specialized implemenSTRING
HIGHexamples/gemm/example_gemm_advanced_autotune.py31 Generate a list of kernel tuning configuration dictionaries for a tiled matrix-multiply. When with_roller is TSTRING
HIGHexamples/gemm/example_gemm_autotune.py23 Generate a list of kernel tuning configuration dictionaries for a tiled matrix-multiply. When with_roller is TSTRING
HIGH…equantize_gemm/example_dequant_gemm_bf16_fp4_hopper.py218 Convert a 4-bit FP4 value packed in a uint8 byte into a bfloat16 value. This helper extracts tSTRING
HIGH…uantize_gemm/example_dequant_gemm_bf16_mxfp4_hopper.py11 Convert a 4-bit field packed in a uint8 into a bfloat16 value, applying an exponent scale. This helper extractSTRING
HIGH…uantize_gemm/example_dequant_gemm_bf16_mxfp4_hopper.py105 Construct and return a tiled matrix-multiply TIR kernel that multiplies A (shape MxK) by a quantized B (shape Nx(QKSTRING
HIGHexamples/dequantize_gemm/dequantize_utils.py5 This function expects `tensor` to be a 2-D torch.Tensor of dtype `torch.uint8`. Each output element is produced by STRING
HIGHexamples/dequantize_gemm/quantize/mxfp.py168 Return metadata for an MXFP decoding intrinsic: function name and C source string. Validates the requested outSTRING
HIGHtilelang/tileop/base.py66 Compute the warp partition (m_warp, n_warp) based on the given policy. Args: M (int): The STRING
HIGHtilelang/tileop/base.py162 Determine the warp policy based on the given warp partitioning. Args: m_warp (int): NumberSTRING
HIGHtilelang/tileop/gemm/__init__.py161Get the appropriate implementation class for the given GEMM instruction key. Args: gemm_inst: The sSTRING
HIGHtilelang/utils/language.py171 Retrieve the single PrimFunc from an IRModule. Args: ir_module (IRModule): The TVM IRModule to extractSTRING
HIGHtilelang/language/kernel.py101Normalize a thread-block specification into a 3-D extent list. Args: threads: A thread count, a per-dimensiSTRING
HIGHtilelang/language/allocate.py104Allocate a single-element variable buffer. Args: dtype (str): The data type of the buffer (e.g., 'float32',STRING
HIGHtilelang/language/customize.py13Perform a four-element signed int8 dot product accumulated into int32. Args: A: First int8 input buffer. STRING
HIGHtilelang/language/copy_op.py65Copy data between memory regions. Args: src (Union[tirx.Buffer, tirx.BufferLoad, tirx.BufferRegion]): SourcSTRING
HIGHtilelang/language/fill_op.py49Clear a buffer by filling it with zeros. Args: buffer: Either a TVM buffer or a variable that contains a buSTRING
HIGHtilelang/language/utils.py63 Compute a flat (linear) index from multi-dimensional coordinates and strides. The function accepts a sequence STRING
HIGHtilelang/language/builtin.py459Wait for memory barrier parity condition. Args: mbarrier: BarrierType The memory barrier toSTRING
HIGHtilelang/language/atomic.py42 Perform an atomic maximum on the value stored at dst with an optional memory-order. Supports scalar/addressed STRING
HIGHtilelang/language/atomic.py128 Atomically update the value at dst to the minimum of its current value and value. Supports scalar/addressed exSTRING
HIGHtilelang/language/atomic.py219 Atomically add `value` into `dst`, returning a handle to the operation. Supports scalar/addressed extern atomiSTRING
HIGHtilelang/language/atomic.py316Perform an atomic addition operation with double-width operands. Args: dst (BufferLikeType): Destination buSTRING
HIGHtilelang/language/atomic.py354Perform an atomic addition operation with quad-width operands. Args: dst (BufferLikeType): Destination buffSTRING
HIGHtilelang/language/atomic.py438 Perform an atomic store of `src` into `dst` with the given memory ordering. Parameters: dst (Buffer): STRING
HIGHtilelang/engine/param.py28 Creates a KernelParam instance from a TVM Buffer object. Args: buffer: TVM Buffer object cSTRING
HIGHtilelang/carver/arch/driver/cuda_driver.py112 Get the number of streaming multiprocessors (SMs) on the CUDA device. Args: device_id (int, optional):STRING
Self-Referential Comments33 hits · 106 pts
SeverityFileLineSnippetContext
MEDIUM…ting/python/language/test_tilelang_language_subtype.py72 # Create a larger tensor and slice to get non-contiguous stridesCOMMENT
MEDIUMexamples/quickstart.py58# Define the kernel (matmul) and compile/lower it into an executable moduleCOMMENT
MEDIUM…_attention/example_tilelang_sparse_gqa_decode_paged.py358 # Create a pool of available physical blocksCOMMENT
MEDIUMtilelang/autodd.py770# This class is written by GeminiCOMMENT
MEDIUMtilelang/tools/plot_layout.py206 # Create a rectangle patch for visualizationCOMMENT
MEDIUMtilelang/cache/__init__.py22# Create a map of singleton instance of KernelCachesCOMMENT
MEDIUMtilelang/layout/layout.py26 # Create an IterVar for each dimension in the shapeCOMMENT
MEDIUMtilelang/layout/layout.py28 # Define an IterVar over the range [0, size) with an associated variable nameCOMMENT
MEDIUMtilelang/layout/fragment.py50 # Create a list of IterVar objects based on shape dimensionsCOMMENT
MEDIUMtilelang/language/parser/__init__.py17# This file is modified from the original version,COMMENT
MEDIUMtilelang/language/parser/operation.py17# This file is modified from the original version,COMMENT
MEDIUMtilelang/language/parser/parser.py17# This file is modified from the original version,COMMENT
MEDIUMtilelang/language/parser/entry.py17# This file is modified from the original version,COMMENT
MEDIUMtilelang/language/ast/_ffi_api.py17# This file is modified from the original version,COMMENT
MEDIUMtilelang/language/ast/__init__.py17# This file is modified from the original version,COMMENT
MEDIUMtilelang/language/ast/ir.py17# This file is modified from the original version,COMMENT
MEDIUMtilelang/contrib/cutedsl/atomic.py112 # Create a tensor from pointer and load elementsCOMMENT
MEDIUMtilelang/jit/kernel.py419 # Create an adapter based on the specified execution backend.COMMENT
MEDIUMtilelang/jit/adapter/wrapper.py626 # Create the host function wrapper for the CUDA kernelCOMMENT
MEDIUMtilelang/jit/adapter/wrapper.py896 # Create the call function wrapper for the CPU kernelCOMMENT
MEDIUMtilelang/jit/adapter/nvrtc/wrapper.py596 # Create the host function wrapper for the CUDA kernelCOMMENT
MEDIUMtilelang/carver/matmul_analysis.py737# This function is used to get the index map for the stage3 of theCOMMENT
MEDIUMtilelang/carver/template/matmul.py87 # Define a reduction axis for matrix multiplicationCOMMENT
MEDIUMtilelang/carver/template/elementwise.py1# Import necessary modulesCOMMENT
MEDIUMtilelang/carver/template/elementwise.py47 # Define a placeholder tensor ACOMMENT
MEDIUMtilelang/carver/template/elementwise.py50 # Define the element-wise computation (adding 1 to each element)COMMENT
MEDIUMtilelang/carver/template/elementwise.py54 # Define the computation for B based on ACOMMENT
MEDIUMtilelang/carver/template/general_reduce.py106 # Create a PrimFunc from placeholders + outputCOMMENT
MEDIUMtilelang/carver/template/flashattention.py77 # Define a reduction axis for matrix multiplicationCOMMENT
MEDIUMtilelang/carver/template/gemv.py72 # Define a reduction axis for matrix multiplicationCOMMENT
MEDIUMtilelang/carver/template/base.py1# Import necessary modules and classesCOMMENT
MEDIUMtilelang/carver/roller/policy/tensorcore.py239 # This function is used to check whether we can implement swizzlingCOMMENT
MEDIUMmaint/precision/compare_ops.py73# Initialize global variablesCOMMENT
Modern Structural Boilerplate88 hits · 90 pts
SeverityFileLineSnippetContext
LOWversion_provider.py99__all__ = ["dynamic_metadata"]CODE
LOWbenchmark/matmul_fp8/benchmark_matmul.py10logger = logging.getLogger(__name__)CODE
LOWbenchmark/matmul/benchmark_matmul.py10logger = logging.getLogger(__name__)CODE
LOWbenchmark/matmul/benchmark_matmul_sp.py17logger = logging.getLogger(__name__)CODE
LOW…g/python/autotune/test_tilelang_autotune_eager_mode.py9logger = logging.getLogger(__name__)CODE
LOW…/python/autotune/test_tilelang_autotune_with_inputs.py9logger = logging.getLogger(__name__)CODE
LOWtilelang/env.py14logger = logging.getLogger(__name__)CODE
LOWtilelang/__init__.py51logger = logging.getLogger(__name__)CODE
LOWtilelang/ir.py101def set_stmt_span(stmt, span: Span) -> None:CODE
LOWtilelang/ir.py110def set_buffer_span(buffer, span: Span) -> None:CODE
LOWtilelang/ir.py119def set_prim_func_span(func, span: Span) -> None:CODE
LOWtilelang/tools/pass_timing.py353__all__ = [CODE
LOWtilelang/tools/Analyzer.py12logger = logging.getLogger(__name__)CODE
LOWtilelang/tools/compile_only.py27__all__ = [CODE
LOWtilelang/tools/cuda/iket/__init__.py26__all__ = [CODE
LOWtilelang/tools/lower_trace/__init__.py35__all__ = [CODE
LOWtilelang/tools/lower_trace/core.py289 def update_html_link(self, run_html_path: str) -> None:CODE
LOWtilelang/tools/lower_trace/core.py713__all__ = [CODE
LOWtilelang/metal/intrinsics/__init__.py5__all__ = ["MPSIntrinEmitter"]CODE
LOWtilelang/metal/transform/mark_host_metal_context.py59__all__ = ["MarkHostMetalContext"]CODE
LOWtilelang/metal/transform/metal_fragment_to_simdgroup.py174__all__ = ["MetalFragmentToSimdgroup"]CODE
LOWtilelang/metal/transform/__init__.py6__all__ = [CODE
LOWtilelang/cuda/language/pdl.py4__all__ = [CODE
LOWtilelang/cuda/language/random.py4__all__ = ["rng_init", "rng_rand", "rng_rand_float"]CODE
LOWtilelang/cuda/language/intrinsics.py80__all__ = [CODE
LOWtilelang/cuda/language/cluster.py6__all__ = [CODE
LOWtilelang/cuda/language/print.py13__all__ = ["device_assert", "print"]CODE
LOWtilelang/cuda/language/warpgroup.py8__all__ = ["WarpSpecialize", "WarpSpecializeFrame", "ws"]CODE
LOWtilelang/cuda/transform/__init__.py161__all__ = [CODE
LOWtilelang/autotuner/tuner.py58logger = logging.getLogger(__name__)CODE
LOWtilelang/language/math_intrinsics.py430__all__ = [CODE
LOWtilelang/language/ws_schedule.py21__all__ = [CODE
LOWtilelang/language/symbolics.py10__all__ = ["dynamic", "symbolic"]CODE
LOWtilelang/language/annotations.py11__all__ = [CODE
LOWtilelang/language/tir/exports.py59__all__ = [CODE
LOWtilelang/language/ast/ir.py1915__all__ = [CODE
LOWtilelang/language/eager/builder.py34logger = logging.getLogger(__name__)CODE
LOWtilelang/backend/pass_pipeline/__init__.py3__all__ = [CODE
LOWtilelang/contrib/cutedsl/gemm_tcgen05.py12__all__ = [CODE
LOWtilelang/contrib/cutedsl/gemm_v1.py1__all__ = [CODE
LOWtilelang/contrib/cutedsl/threadblock_swizzle.py1__all__ = [CODE
LOWtilelang/contrib/cutedsl/reduce.py8__all__ = [CODE
LOWtilelang/contrib/cutedsl/quantize.py9__all__ = [CODE
LOWtilelang/contrib/cutedsl/ldsm.py9__all__ = [CODE
LOWtilelang/contrib/cutedsl/ieee_math.py10__all__ = [CODE
LOWtilelang/contrib/cutedsl/utils.py37__all__ = [CODE
LOWtilelang/contrib/cutedsl/cluster.py7__all__ = [CODE
LOWtilelang/contrib/cutedsl/grid_sync.py17__all__ = ["sync_grid"]CODE
LOWtilelang/contrib/cutedsl/warp.py8__all__ = [CODE
LOWtilelang/contrib/cutedsl/math.py1__all__ = [CODE
LOWtilelang/contrib/cutedsl/atomic.py7__all__ = [CODE
LOWtilelang/contrib/cutedsl/ptx_mma.py25__all__ = [CODE
LOWtilelang/contrib/cutedsl/cpasync.py3__all__ = [CODE
LOWtilelang/contrib/cutedsl/gemm_v2.py1__all__ = [CODE
LOWtilelang/instrumentation/events.py251__all__ = [CODE
LOWtilelang/instrumentation/session.py277__all__ = [CODE
LOWtilelang/instrumentation/__init__.py29__all__ = [CODE
LOWtilelang/testing/__init__.py16__all__ = [CODE
LOWtilelang/testing/__init__.py100def set_random_seed(seed: int = 42) -> None:CODE
LOWtilelang/jit/kernel.py33logger = logging.getLogger(__name__)CODE
28 more matches not shown…
Hallucination Indicators3 hits · 40 pts
SeverityFileLineSnippetContext
CRITICALexamples/kda/FLA_KDA/fla_utils.py118# return triton.runtime.driver.active.utils.get_device_properties(tensor_idx)['multiprocessor_count']COMMENT
CRITICALexamples/kda/FLA_KDA/fla_utils.py122# return triton.runtime.driver.active.utils.get_device_properties(tensor_idx)['num_vectorcore']COMMENT
CRITICALexamples/kda/FLA_KDA/fla_utils.py227 triton.runtime.driver.active.utils.get_device_properties(i)["max_shared_mem"] for i in range(device_torch_liCODE
Redundant / Tautological Comments19 hits · 27 pts
SeverityFileLineSnippetContext
LOWformat.sh113# Check if there are any uncommitted changes after all formatting steps.COMMENT
LOW…transform/test_tilelang_transform_split_host_device.py260 # Check if this is a top-level dangling declarationCOMMENT
LOW…transform/test_tilelang_transform_split_host_device.py269 # Check if line before assume has dangling varCOMMENT
LOW…tion/example_tilelang_sparse_gqa_decode_varlen_mask.py328 cache_seqlens[random_index] = max_cache_seqlen # Assign cache_seqlen to ensure at least one occurrenceCODE
LOW…tion/example_triton_sparse_gqa_decode_varlen_indice.py339 cache_seqlens[random_index] = max_cache_seqlen # Assign cache_seqlen to ensure at least one occurrenceCODE
LOW…ention/example_triton_sparse_gqa_decode_varlen_mask.py333 cache_seqlens[random_index] = max_cache_seqlen # Assign cache_seqlen to ensure at least one occurrenceCODE
LOWexamples/deepseek_v32/sparse_mla_fwd_seesaw.py223 # Check if 384 threads have already arrived at bar_q (phase0 completed),COMMENT
LOWtilelang/autotuner/tuner.py944 # Check if all tunable arguments have been tuned by comparing config keys with key_kwargs_tupleCOMMENT
LOWtilelang/utils/tensor.py57 # Check if with dynamic symbolic shapeCOMMENT
LOWtilelang/language/dtypes.py190 # Check if we're on HIP (AMD ROCm) or CUDACOMMENT
LOWtilelang/language/atomic.py237 >>> atomic_add(counter, 1) # Increment counter by 1STRING
LOWtilelang/contrib/cutedsl/grid_sync.py54 # Check if the globals already exist.COMMENT
LOWtilelang/jit/adapter/cutedsl/adapter.py352 # Check if we have a cache path (set by kernel_cache)COMMENT
LOWtilelang/jit/adapter/nvrtc/wrapper.py341 # Check if any function needs L2 Persistent MapCOMMENT
LOWtilelang/jit/adapter/nvrtc/__init__.py12# Check if cuda-python is availableCOMMENT
LOWtilelang/engine/lower.py36 # Check if it's a C targetCOMMENT
LOWtilelang/transform/decouple_type_cast.py402 # Check if the normalized body has any Cast nodes.COMMENT
LOWtilelang/carver/template/conv.py128 # Check if the input position is within bounds (implicit padding with 0)COMMENT
LOWmaint/scripts/run_local_ci_test.sh74# Set ROOT_DIR to the project root (two levels up from this script's directory)COMMENT
Structural Annotation Overuse10 hits · 13 pts
SeverityFileLineSnippetContext
LOWdocs/tutorials/auto_tuning.md19### Step 1: Implement with Reserved ParametersCOMMENT
LOWdocs/tutorials/auto_tuning.md45### Step 2: Generate Candidate ConfigurationsCOMMENT
LOWdocs/tutorials/auto_tuning.md99### Step 3: Compile and BenchmarkCOMMENT
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py44 # Step 1: Compute gate and up logitsCOMMENT
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py74 # Step 2: Compute down logitsCOMMENT
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py144 # Step 1: Compute gate and up logitsCOMMENT
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py192 # Step 2: Compute down logitsCOMMENT
LOWtilelang/jit/adapter/cutedsl/wrapper.py547 // Step 1: Unload modules for all devicesCOMMENT
LOWtilelang/jit/adapter/cutedsl/wrapper.py560 // Step 2: Release primary contexts (must execute even if module unload failed)COMMENT
LOWtilelang/jit/adapter/cutedsl/wrapper.py584 // Step 3: Clear all mapsCOMMENT
AI Slop Vocabulary4 hits · 9 pts
SeverityFileLineSnippetContext
MEDIUMexamples/attention_sink/benchmark_mha_sink_fwd.py81 p = p.to(v.dtype) # We perform fp16 gemm to utilize tensor coreCODE
MEDIUMexamples/attention_sink/benchmark_gqa_sink_fwd.py82 p = p.to(v.dtype) # We perform fp16 gemm to utilize tensor coreCODE
MEDIUMtilelang/cache/kernel_cache.py274 "args_repr": tuple(repr(arg) for arg in args), # Use repr to serialize arguments, may need more robust seriCODE
MEDIUMtilelang/carver/matmul_analysis.py526 # step1. detect whether the function can utilize tensorcoreCOMMENT
Verbosity Indicators7 hits · 8 pts
SeverityFileLineSnippetContext
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py44 # Step 1: Compute gate and up logitsCOMMENT
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py74 # Step 2: Compute down logitsCOMMENT
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py144 # Step 1: Compute gate and up logitsCOMMENT
LOWexamples/fusedmoe/example_fusedmoe_tilelang.py192 # Step 2: Compute down logitsCOMMENT
LOWtilelang/jit/adapter/cutedsl/wrapper.py547 // Step 1: Unload modules for all devicesCOMMENT
LOWtilelang/jit/adapter/cutedsl/wrapper.py560 // Step 2: Release primary contexts (must execute even if module unload failed)COMMENT
LOWtilelang/jit/adapter/cutedsl/wrapper.py584 // Step 3: Clear all mapsCOMMENT
Dead Code3 hits · 6 pts
SeverityFileLineSnippetContext
MEDIUM…sparse_attention/benchmark_triton_block_sparse_fmha.py248CODE
MEDIUM…ples/blocksparse_attention/block_sparse_attn_triton.py248CODE
MEDIUMexamples/seer_attention/block_sparse_attn_triton.py243CODE
Example Usage Blocks3 hits · 4 pts
SeverityFileLineSnippetContext
LOWformat.sh2# Usage:COMMENT
LOWmaint/scripts/run_local_ci_test.sh3# Usage:COMMENT
LOWmaint/scripts/run_perf_regression.sh8# Usage:COMMENT
Modern AI Meta-Vocabulary1 hit · 3 pts
SeverityFileLineSnippetContext
MEDIUMmaint/scripts/run_perf_regression.sh4# This script orchestrates the newer Python primitives:COMMENT
TODO Padding1 hit · 2 pts
SeverityFileLineSnippetContext
LOW3rdparty/hip-headers/include/hip/hip_runtime_api.h2500// TODO: implement IPC apisCOMMENT
Fake / Example Data1 hit · 1 pts
SeverityFileLineSnippetContext
LOWtilelang/carver/roller/node.py187 return "placeholder"CODE
Overly Generic Function Names1 hit · 0 pts
SeverityFileLineSnippetContext
LOWtilelang/language/eager/ast.py684 ... def my_function(x: int) -> int:STRING